# Generated by Django 3.1.2 on 2021-01-13 08:28

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('opcalendar', '0012_auto_20210112_0934'),
    ]

    operations = [
        migrations.AddField(
            model_name='eventimport',
            name='creator',
            field=models.ForeignKey(default='1', on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]



from django.forms import ModelForm, DateInput
from django.forms.widgets import TextInput
from opcalendar.models import Event, EventMember, EventCategory
from django import forms

from django.utils.translation import ugettext_lazy as _

class EventForm(ModelForm):
  class Meta:
    model = Event
    # datetime-local is a HTML5 input type, format to make date time show on fields
    widgets = {
      'start_time': DateInput(attrs={'type': 'datetime-local'}, format='%Y-%m-%dT%H:%M'),
      'end_time': DateInput(attrs={'type': 'datetime-local'}, format='%Y-%m-%dT%H:%M'),
    }
    exclude = ['user','eve_character','created_date']

  def __init__(self, *args, **kwargs):
    super(EventForm, self).__init__(*args, **kwargs)
    # input_formats to parse HTML5 datetime-local input to datetime field
    self.fields['start_time'].input_formats = ('%Y-%m-%dT%H:%M',)
    self.fields['end_time'].input_formats = ('%Y-%m-%dT%H:%M',)


class SignupForm(forms.Form):
  username = forms.CharField(widget=forms.TextInput(attrs={'class': 'form-control', 'placeholder': 'Username'}))
  password = forms.CharField(widget=forms.PasswordInput(attrs={'class': 'form-control', 'placeholder': 'Password'}))


class AddMemberForm(forms.ModelForm):
  class Meta:
    model = EventMember
    fields = ['user']

class AddCategoryForm(forms.ModelForm):
  class Meta:
    model = EventCategory
    fields = '__all__'




from django.conf import settings
from .utils import clean_setting
import re

def get_site_url():  # regex sso url
    regex = r"^(.+)\/s.+"
    matches = re.finditer(regex, settings.ESI_SSO_CALLBACK_URL, re.MULTILINE)
    url = "http://"

    for m in matches:
        url = m.groups()[0] # first match

    return url

# Hard timeout for tasks in seconds to reduce task accumulation during outages
OPCALENDAR_TASKS_TIME_LIMIT = clean_setting("OPCALENDAR_TASKS_TIME_LIMIT", 7200)

# whether admins will get notifications about import events
OPCALENDAR_ADMIN_NOTIFICATIONS_ENABLED = clean_setting(
    "OPCALENDAR_ADMIN_NOTIFICATIONS_ENABLED", True
)

# whether we should send out discord notifications for imported fleets
OPCALENDAR_NOTIFY_IMPORTS = clean_setting(
    "OPCALENDAR_NOTIFY_IMPORTS", True
)

OPCALENDAR_EVE_UNI_URL = "https://portal.eveuniversity.org/api/getcalendar"
OPCALENDAR_SPECTRE_URL = "https://www.spectre-fleet.space/engagement/events/rss"



from celery import shared_task
from datetime import datetime
from django.utils import timezone
import pytz
import feedparser
import logging
import re
from dateutil.parser import parse
from .models import Event, EventImport, Owner

from .app_settings import OPCALENDAR_TASKS_TIME_LIMIT
from bravado.exception import HTTPBadGateway, HTTPGatewayTimeout, HTTPServiceUnavailable
from allianceauth.services.tasks import QueueOnce
from ics import Calendar
import requests

import random


from celery import shared_task

from allianceauth.services.hooks import get_extension_logger
from allianceauth.services.tasks import QueueOnce
from esi.models import Token

from .app_settings import (
    OPCALENDAR_EVE_UNI_URL,
    OPCALENDAR_SPECTRE_URL,
)

DEFAULT_TASK_PRIORITY = 6

logger = get_extension_logger(__name__)

# Create your tasks here
TASK_DEFAULT_KWARGS = {
    "time_limit": OPCALENDAR_TASKS_TIME_LIMIT,
}

TASK_ESI_KWARGS = {
    **TASK_DEFAULT_KWARGS,
    **{
        "bind": True,
        "autoretry_for": (
            OSError,
            HTTPBadGateway,
            HTTPGatewayTimeout,
            HTTPServiceUnavailable,
        ),
        "retry_kwargs": {"max_retries": 3},
        "retry_backoff": 30,
    },
}



# Import eve uni classes
@shared_task
def import_fleets():
	
	#Get all current imported fleets in database
	event_ids_to_remove = list(
    	Event.objects.filter(visibility="import").values_list("id", flat=True)
    )
	local_tz = pytz.timezone("UTC")

	#Get all import feeds
	feeds = EventImport.objects.all()
	
	for feed in feeds:
		if feed.source=="Spectre Fleet":
			logger.debug("Spectre Fleet import feed active. Pulling events from %s" % OPCALENDAR_SPECTRE_URL)
			#Get fleets from SF RSS
			d = feedparser.parse(OPCALENDAR_SPECTRE_URL)
			for entry in d.entries:
				##Look for SF fleets only
				if entry.author_detail.name=='Spectre Fleet':
					#Only active fleets
					if not "[RESERVED]" in entry.title:

						logger.debug("Import even found: %s" % entry.title)
						
						date_object = datetime.strptime(entry.published,'%a, %d %b %Y %H:%M:%S %z')
						date_object.strftime('%Y-%m-%dT%H:%M')

						# Check if we already have the event stored
						original = Event.objects.filter(start_time=date_object, title=entry.title).first()

						#If we get the event from API it should not be removed
						if original is not None:
							logger.debug("Event: %s already in database" % entry.title)
							event_ids_to_remove.remove(original.id)

						else:
							event = Event(
								operation_type=feed.operation_type,
								title=entry.title,
								host=feed.host,
								doctrine="",
								formup_system="",
								description=entry.description,
								start_time=date_object, 
								end_time=date_object, 
								fc="",
								visibility="import",
								user_id = feed.creator.id,
								eve_character_id = feed.eve_character.id
							)
							
							logger.debug("Saved new event in database: %s" % entry.title)
							
							event.save()

		if feed.source=="EVE University":
			logger.debug("EVE University import feed active. Pulling events from %s" % OPCALENDAR_EVE_UNI_URL)
			#Get fleets from EVE UNI Ical
			url = OPCALENDAR_EVE_UNI_URL
			c = Calendar(requests.get(url).text)
			for entry in c.events:
				#Filter only class events as they are the only public events in eveuni
				
				if "class" in entry.name.lower():

					start_date = datetime.utcfromtimestamp(entry.begin.timestamp).replace(tzinfo=pytz.utc)
					end_date = datetime.utcfromtimestamp(entry.end.timestamp).replace(tzinfo=pytz.utc)
					title = re.sub("[\(\[].*?[\)\]]", "", entry.name)

					logger.debug("Import even found: %s" % title)

					# Check if we already have the event stored
					original = Event.objects.filter(start_time=start_date, title=title).first()

					#If we get the event from API it should not be removed	
					if original is not None:
						logger.debug("Event: %s already in database" % title)
						event_ids_to_remove.remove(original.id)

					else:		
						event = Event(
							operation_type=feed.operation_type,
							title=title,
							host=feed.host,
							doctrine="",
							formup_system="",
							description=entry.description,
							start_time=start_date, 
							end_time=end_date, 
							fc="",
							visibility="import",
							user_id = feed.creator.id,
							eve_character_id = feed.eve_character.id
						)

						logger.debug("Saved new event in database: %s" % title)
						event.save()
	logger.debug("Removing all events that we did not get over API")
	# Remove all events we did not see from API					
	Event.objects.filter(pk__in=event_ids_to_remove).delete()

@shared_task(
    **{
        **TASK_ESI_KWARGS,
        **{
            "base": QueueOnce,
            "once": {"keys": ["owner_pk"], "graceful": True},
            "max_retries": None,
        },
    }
)
def update_events_for_owner(self, owner_pk):
    """fetches all calendars for owner from ESI"""

    return _get_owner(owner_pk).update_events_esi()

@shared_task(**TASK_DEFAULT_KWARGS)
def update_all_ingame_events():
    for owner in Owner.objects.all():
        update_events_for_owner.apply_async(
            kwargs={"owner_pk": owner.pk},
            priority=DEFAULT_TASK_PRIORITY,
        )


def _get_owner(owner_pk: int) -> Owner:
    """returns the owner or raises exception"""
    try:
        owner = Owner.objects.get(pk=owner_pk)
    except Owner.DoesNotExist:
        raise Owner.DoesNotExist(
            "Requested owner with pk {} does not exist".format(owner_pk)
        )
    return owner


@shared_task
def add(x, y):
    return x + y

   


# Generated by Django 3.1.2 on 2021-01-13 09:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0012_index_additions'),
        ('opcalendar', '0014_auto_20210113_0836'),
    ]

    operations = [
        migrations.AddField(
            model_name='eventimport',
            name='eve_character',
            field=models.ForeignKey(help_text='Event creator main character', null=True, on_delete=django.db.models.deletion.SET_NULL, to='eveonline.evecharacter'),
        ),
    ]



# calendarapp/utils.py
import logging

from datetime import datetime, timedelta, date, timezone
from calendar import HTMLCalendar
from eventcalendar.helper import get_current_user
from typing import Any

from django.contrib import messages
from django.conf import settings
from django.contrib.messages.constants import DEBUG, ERROR, INFO, SUCCESS, WARNING
from django.utils.translation import ugettext_lazy as _
from django.utils.html import format_html

from allianceauth.services.hooks import get_extension_logger

from .models import Event, IngameEvents

logger = get_extension_logger(__name__)

class Calendar(HTMLCalendar):
	def __init__(self, year=None, month=None, user=None):
		self.year = year
		self.month = month
		self.user = user
		super(Calendar, self).__init__()
		
	# formats a day as a td
	# filter events by day
	def formatday(self, day, events, ingame_events):
		events_per_day = events.filter(start_time__day=day).order_by('start_time')
		ingame_events_per_day = ingame_events.filter(event_start_date__day=day).order_by('event_start_date')
		d = ''
		
		# Only events for current month
		if day != 0:
			# Parse events
			for event in events_per_day:
				#Display public events
				if event.visibility == "public" or event.visibility == "import" and self.user.has_perm('opcalendar.view_public'):
					#Get past events
					if datetime.now(timezone.utc) > event.start_time:
						d += f'<a class="nostyling" href="{event.get_html_url}"><div class="event {event.get_html_operation_color} past-event {event.visibility}-event">{event.get_html_title}</div></a>'
					if datetime.now(timezone.utc) <= event.start_time:
						d += f'<a class="nostyling" href="{event.get_html_url}"><div class="event {event.get_html_operation_color} {event.visibility}-event">{event.get_html_title}</div></a>'
				if event.visibility == "member" and self.user.has_perm('opcalendar.view_member'):
					#Get past events
					if datetime.now(timezone.utc) > event.start_time:
						d += f'<a class="nostyling" href="{event.get_html_url}"><div class="event {event.get_html_operation_color} past-event {event.visibility}-event">{event.get_html_title}</div></a>'
					if datetime.now(timezone.utc) <= event.start_time:
						d += f'<a class="nostyling" href="{event.get_html_url}"><div class="event {event.get_html_operation_color} {event.visibility}-event">{event.get_html_title}</div></a>'
			for event in ingame_events_per_day:
				if self.user.has_perm('opcalendar.view_ingame'):
					#Get past events
					if datetime.now(timezone.utc) > event.event_start_date:
						d += f'<a class="nostyling" href="{event.get_html_url}"><div class="event {event.get_html_operation_color} past-event import-event">{event.get_html_title}</div></a>'
					if datetime.now(timezone.utc) <= event.event_start_date:
						d += f'<a class="nostyling" href="{event.get_html_url}"><div class="event {event.get_html_operation_color} import-event">{event.get_html_title}</div></a>'

			if date.today() == date(self.year, self.month, day):
				return f"<td class='today'><div class='date'>{day}</div> {d}</td>"
			return f"<td><div class='date'>{day}</div> {d}</td>"
		return '<td></td>'

	# formats a week as a tr 
	def formatweek(self, theweek, events, ingame_events):
		week = ''
		for d, weekday in theweek:
			week += self.formatday(d, events, ingame_events)
		return f'<tr> {week} </tr>'

	# formats a month as a table
	# filter events by year and month
	def formatmonth(self, withyear=True):
		events = Event.objects.filter(start_time__year=self.year, start_time__month=self.month)
		ingame_events = IngameEvents.objects.filter(event_start_date__year=self.year, event_start_date__month=self.month)
		
		cal = f'<table border="0" cellpadding="0" cellspacing="0" class="calendar">\n'
		cal += f'{self.formatmonthname(self.year, self.month, withyear=withyear)}\n'
		cal += f'{self.formatweekheader()}\n'
		for week in self.monthdays2calendar(self.year, self.month):
			cal += f'{self.formatweek(week, events, ingame_events)}\n'
		return cal

def clean_setting(
    name: str,
    default_value: object,
    min_value: int = None,
    max_value: int = None,
    required_type: type = None,
    choices: list = None,
) -> Any:
    """cleans the input for a custom setting

    Will use `default_value` if settings does not exit or has the wrong type
    or is outside define boundaries (for int only)

    Need to define `required_type` if `default_value` is `None`

    Will assume `min_value` of 0 for int (can be overriden)

    `None` allowed as value

    Returns cleaned value for setting
    """
    if default_value is None and not required_type:
        raise ValueError("You must specify a required_type for None defaults")

    if not required_type:
        required_type = type(default_value)

    if min_value is None and required_type == int:
        min_value = 0

    if not hasattr(settings, name):
        cleaned_value = default_value
    else:
        dirty_value = getattr(settings, name)
        if dirty_value is None or (
            isinstance(dirty_value, required_type)
            and (min_value is None or dirty_value >= min_value)
            and (max_value is None or dirty_value <= max_value)
            and (choices is None or dirty_value in choices)
        ):
            cleaned_value = dirty_value
        else:
            logger.warn(
                "You setting for {} it not valid. Please correct it. "
                "Using default for now: {}".format(name, default_value)
            )
            cleaned_value = default_value
    return cleaned_value

class messages_plus:
    """Pendant to Django messages adding level icons and HTML support

    Careful: Use with safe strings only
    """

    _glyph_map = {
        DEBUG: "eye-open",
        INFO: "info-sign",
        SUCCESS: "ok-sign",
        WARNING: "exclamation-sign",
        ERROR: "alert",
    }

    @classmethod
    def _add_messages_icon(cls, level: int, message: str) -> str:
        """Adds an level based icon to standard Django messages"""
        if level not in cls._glyph_map:
            raise ValueError("glyph for level not defined")
        else:
            glyph = cls._glyph_map[level]

        return format_html(
            '<span class="glyphicon glyphicon-{}" '
            'aria-hidden="true"></span>&nbsp;&nbsp;{}',
            glyph,
            message,
        )

    @classmethod
    def debug(
        cls,
        request: object,
        message: str,
        extra_tags: str = "",
        fail_silently: bool = False,
    ):
        messages.debug(
            request, cls._add_messages_icon(DEBUG, message), extra_tags, fail_silently
        )

    @classmethod
    def info(
        cls,
        request: object,
        message: str,
        extra_tags: str = "",
        fail_silently: bool = False,
    ):
        messages.info(
            request, cls._add_messages_icon(INFO, message), extra_tags, fail_silently
        )

    @classmethod
    def success(
        cls,
        request: object,
        message: str,
        extra_tags: str = "",
        fail_silently: bool = False,
    ):
        messages.success(
            request, cls._add_messages_icon(SUCCESS, message), extra_tags, fail_silently
        )

    @classmethod
    def warning(
        cls,
        request: object,
        message: str,
        extra_tags: str = "",
        fail_silently: bool = False,
    ):
        messages.warning(
            request, cls._add_messages_icon(WARNING, message), extra_tags, fail_silently
        )

    @classmethod
    def error(
        cls,
        request: object,
        message: str,
        extra_tags: str = "",
        fail_silently: bool = False,
    ):
        messages.error(
            request, cls._add_messages_icon(ERROR, message), extra_tags, fail_silently
        )



from django.dispatch import receiver

from django.db.models.signals import post_save, pre_delete, pre_save
from allianceauth.groupmanagement.models import GroupRequest
from allianceauth.authentication.models import UserProfile, CharacterOwnership, EveCharacter
from allianceauth.eveonline.evelinks.eveimageserver import  type_icon_url, character_portrait_url
from .models import Event, EventSignal, IngameEvents
import requests
import json
import datetime
from django.utils import timezone

from esi.clients import EsiClientProvider

from .app_settings import get_site_url
from .helpers import time_helpers

from allianceauth.services.hooks import get_extension_logger
logger = get_extension_logger(__name__)

from django.utils.translation import ugettext_lazy as _

from .app_settings import (
    OPCALENDAR_NOTIFY_IMPORTS,
)

RED = 16711710
BLUE = 42751
GREEN = 6684416

esi = EsiClientProvider()

@receiver(post_save, sender=Event)
@receiver(post_save, sender=IngameEvents)
def fleet_saved(sender, instance, created, **kwargs):
     
    # Translate titles if we have ingame events
    if sender == IngameEvents:
        instance.visibility = ""

    if not "import" in instance.visibility or OPCALENDAR_NOTIFY_IMPORTS:
        try:
            logger.debug("New signal fleet created for %s" % instance.title)
            url = get_site_url() + "/optimer/"
            
            # Translate titles if we have ingame events
            if sender == IngameEvents:
                
                message = "New Event Created From API Feed"

                # Get the entity name from owner name
                entity_id = esi.client.Search.get_search(
                    categories=[instance.owner_type],
                    search=instance.owner_name, 
                    strict=True).results()[instance.owner_type][0]

                logger.debug("Entity data is %s" % entity_id)
                
                main_char = instance.owner.character.character.character_name
                
                formup_system = instance.owner_name
                
                title = instance.title
                
                doctrine = ""
                
                eve_time = instance.event_start_date
                
                fc = instance.owner_name
                
                # Setup portrait URL based on owner type
                if instance.owner_type == "alliance":
                    portrait = "https://images.evetech.net/alliances/{}/logo".format(entity_id)
                    ticker = "[{}]".format(esi.client.Alliance.get_alliances_alliance_id(
                        alliance_id = entity_id
                        ).results()["ticker"])

                if instance.owner_type == "corporation":
                    portrait = "https://images.evetech.net/corporations/{}/logo".format(entity_id)
                    ticker = "[{}]".format(esi.client.Corporation.get_corporations_corporation_id(
                        corporation_id = entity_id
                        ).results()["ticker"])

                if instance.owner_type == "character": 
                    portrait = "https://images.evetech.net/characters/{}/portrait".format(entity_id) 
                    ticker = ""

                logger.debug("Portrait url is %s" % portrait)

                character_name = instance.owner_name            

            else:

                message = "New Fleet Event "

                main_char = instance.eve_character
                
                formup_system = instance.formup_system
                
                title = instance.title
                
                doctrine = instance.doctrine
                
                eve_time = instance.start_time
                
                fc = instance.fc

                portrait = main_char.portrait_url_64

                character_name = main_char.character_name

                ticker = "{}".format(main_char.corporation_ticker)

            #If we update instead of delete
            if not created:
                message = "Event Updated"
                col = BLUE
            else:
                col = GREEN

            embed = {'title': message, 
                    'description': ("**{}** from **{}**".format(title,formup_system)),
                    'url': url,
                    'color': col,
                    "fields": [
                        {
                        "name": "FC",
                        "value": fc,
                        "inline": True
                        },
                        {
                        "name": "Eve Time",
                        "value": eve_time.strftime("%Y-%m-%d %H:%M:%S")
                        }

                    ],
                    "footer": {
                        "icon_url": portrait,
                        "text": "{}  {}".format(character_name, ticker)
                    }
                }

            hooks = EventSignal.objects.all().select_related('webhook')
            old = datetime.datetime.now(timezone.utc) > eve_time

            for hook in hooks:
                if hook.webhook.enabled:
                    if old and hook.ignore_past_fleets:
                        continue
                    hook.webhook.send_embed(embed)

        except Exception as e:
            logger.error(e)
            pass  # shits fucked... Don't worry about it...

@receiver(pre_delete, sender=Event)
@receiver(pre_delete, sender=IngameEvents)
def fleet_deleted(sender, instance, **kwargs):
     
    # Translate titles if we have ingame events
    if sender == IngameEvents:
        instance.visibility = ""

    if not "import" in instance.visibility or OPCALENDAR_NOTIFY_IMPORTS:
        try:
            logger.debug("New signal fleet deleted for %s" % instance.title)
            url = get_site_url() + "/optimer/"
            
            # Translate titles if we have ingame events
            if sender == IngameEvents:
                
                message = "Event Removed Via API Feed"

                # Get the entity name from owner name
                entity_id = esi.client.Search.get_search(
                    categories=[instance.owner_type],
                    search=instance.owner_name, 
                    strict=True).results()[instance.owner_type][0]

                logger.debug("Entity data is %s" % entity_id)
                
                main_char = instance.owner.character.character.character_name
                
                formup_system = instance.owner_name
                
                title = instance.title
                
                doctrine = ""
                
                eve_time = instance.event_start_date
                
                fc = instance.owner_name
                
                # Setup portrait URL based on owner type
                if instance.owner_type == "alliance":
                    portrait = "https://images.evetech.net/alliances/{}/logo".format(entity_id)
                    ticker = "[{}]".format(esi.client.Alliance.get_alliances_alliance_id(
                        alliance_id = entity_id
                        ).results()["ticker"])

                if instance.owner_type == "corporation":
                    portrait = "https://images.evetech.net/corporations/{}/logo".format(entity_id)
                    ticker = "[{}]".format(esi.client.Corporation.get_corporations_corporation_id(
                        corporation_id = entity_id
                        ).results()["ticker"])

                if instance.owner_type == "character": 
                    portrait = "https://images.evetech.net/characters/{}/portrait".format(entity_id) 
                    ticker = ""

                logger.debug("Portrait url is %s" % portrait)

                character_name = instance.owner_name            

            else:

                message = "Fleet Event Removed"

                main_char = instance.eve_character
                
                formup_system = instance.formup_system
                
                title = instance.title
                
                doctrine = instance.doctrine
                
                eve_time = instance.start_time
                
                fc = instance.fc

                portrait = main_char.portrait_url_64

                character_name = main_char.character_name

                ticker = "{}".format(main_char.corporation_ticker)

            embed = {'title': message, 
                    'description': ("**{}** from **{}** has been cancelled".format(title,formup_system)),
                    'url': url,
                    'color': RED,
                    "fields": [
                        {
                        "name": "FC",
                        "value": fc,
                        "inline": True
                        },
                        {
                        "name": "Eve Time",
                        "value": eve_time.strftime("%Y-%m-%d %H:%M:%S")
                        }

                    ],
                    "footer": {
                        "icon_url": portrait,
                        "text": "{}  {}".format(character_name, ticker)
                    }
                }

            hooks = EventSignal.objects.all().select_related('webhook')
            old = datetime.datetime.now(timezone.utc) > eve_time

            for hook in hooks:
                if hook.webhook.enabled:
                    if old and hook.ignore_past_fleets:
                        continue
                    hook.webhook.send_embed(embed)

        except Exception as e:
            logger.error(e)
            pass  # shits fucked... Don't worry about it...


# Generated by Django 3.1.2 on 2020-11-04 12:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('opcalendar', '0006_auto_20201104_1201'),
    ]

    operations = [
        migrations.AddField(
            model_name='eventhost',
            name='twitter',
            field=models.CharField(blank=True, max_length=150),
        ),
    ]



from esi.clients import EsiClientProvider
import os
from . import __version__

def get_swagger_spec_path() -> str:
    """returns the path to the current swagger spec file"""
    return os.path.join(os.path.dirname(os.path.abspath(__file__)), "swagger.json")

esi = EsiClientProvider(
    spec_file=get_swagger_spec_path(), app_info_text=f"aa-opcalendar v{__version__}"
)
 


# Generated by Django 3.1.2 on 2021-01-19 16:26

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0012_index_additions'),
        ('authentication', '0017_remove_fleetup_permission'),
        ('opcalendar', '0016_auto_20210119_1545'),
    ]

    operations = [
        migrations.AlterField(
            model_name='owner',
            name='character',
            field=models.ForeignKey(blank=True, default=None, help_text='Character used for syncing the calendar', null=True, on_delete=django.db.models.deletion.SET_DEFAULT, related_name='+', to='authentication.characterownership'),
        ),
        migrations.AlterField(
            model_name='owner',
            name='corporation',
            field=models.OneToOneField(blank=True, default=None, help_text='Corporation owning the calendar', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='eveonline.evecorporationinfo'),
        ),
    ]
